@@ -137,21 +137,19 @@ def import_gpxfile(gpxfile, pb):
     mydb = db.radar_db()
     
     doc = etree.parse(gpxfile)
-    mainNS=string.Template("{http://www.topografix.com/GPX/1/0}$tag")
-
-    wptTag=mainNS.substitute(tag="wpt")
-    nameTag=mainNS.substitute(tag="name")
+    root = doc.getroot()
 
     radar_total=0
-    for wpt in doc.findall("//"+wptTag):
+    for wpt in root:
         radar_total += 1
     print ("Radar count : %s" % radar_total)
     import_step = 1.0/radar_total
     
     progress_status = 0.0
     i=0
-    for wpt in doc.findall("//"+wptTag):
-        mydb.insert_radar(wpt.get("lat"),  wpt.get("lon"), wpt.findtext(nameTag).encode())
+    for wpt in root:
+        print (wpt.attrib['lat'],  wpt.attrib['lon'], wpt.find(root.tag[:-3] + 'name').text)
+        mydb.insert_radar(wpt.attrib['lat'],  wpt.attrib['lon'], wpt.find(root.tag[:-3] + 'name').text)
         progress_status+=import_step
         i+=1
         pb.set_fraction(progress_status)
